@@ -24,8 +24,8 @@ def tilescache_wsgi(tiles_storage=None, map_server=None):
 2013 <a href="http://ondrejsika.com">Ondrej Sika</a>, 
 <a href="http://ondrejsika.com/docs/tilescache">homepage</a>"""
 
-    @app.route("/tile/<s>/<z>/<y>/<x>.png")
-    def tile(s, z, y, x):
+    @app.route("/tile/<s>/<z>/<x>/<y>.png")
+    def tile(s, z, x, y):
         hash = hashlib.sha1("%s-%s-%s"%(z, y, x)).hexdigest()
         file_dir = normpath(tiles_storage, hash[0:4], hash[5:8], hash[9:12])
         file_path = normpath(file_dir, "%s.png"%hash[:12])
@@ -55,4 +55,4 @@ def tilescache_wsgi(tiles_storage=None, map_server=None):
 
     return app
 
-app = tilescache_wsgi()
\ No newline at end of file
+app = tilescache_wsgi()
